==> vtk-v1.3.x.zip: vtk-v1.3.x/graphics/vtkGraphics.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkGraphics.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-1996 Ken Martin, Will Schroeder, Bill Lorensen.

This software is copyrighted by Ken Martin, Will Schroeder and Bill Lorensen.
The following terms apply to all files associated with the software unless
explicitly disclaimed in individual files. This copyright specifically does
not apply to the related textbook "The Visualization Toolkit" ISBN
013199837-4 published by Prentice Hall which is covered by its own copyright.

The authors hereby grant permission to use, copy, and distribute this
software and its documentation for any purpose, provided that existing
copyright notices are retained in all copies and that this notice is included
verbatim in any distributions. Additionally, the authors grant permission to
modify this software and its documentation for any purpose, provided that
such modifications are not distributed without the explicit consent of the
authors and that existing copyright notices are retained in all copies. Some
of the algorithms implemented by this software are patented, observe all
applicable patent law.

IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY FOR
DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY DERIVATIVES THEREOF,
EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE IS PROVIDED ON AN
"AS IS" BASIS, AND THE AUTHORS AND DISTRIBUTORS HAVE NO OBLIGATION TO PROVIDE
MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.


=========================================================================*/

#include "vtkActor.h"
#include "vtkAppendFilter.h"
#include "vtkAppendPolyData.h"
#include "vtkAssembly.h"
#include "vtkAxes.h"
#include "vtkBYUReader.h"
#include "vtkBYUWriter.h"
#include "vtkBooleanStructuredPoints.h"
#include "vtkBooleanTexture.h"
#include "vtkBrownianPoints.h"
#include "vtkCamera.h"
#include "vtkCastToConcrete.h"
#include "vtkCellLocator.h"
#include "vtkCellPicker.h"
#include "vtkCleanPolyData.h"
#include "vtkClipPolyData.h"
#include "vtkCone.h"
#include "vtkConeSource.h"
#include "vtkConnectivityFilter.h"
#include "vtkContourFilter.h"
#include "vtkCubeSource.h"
#include "vtkCursor3D.h"
#include "vtkCutter.h"
#include "vtkCyberReader.h"
#include "vtkCylinder.h"
#include "vtkCylinderSource.h"
#include "vtkDashedStreamLine.h"
#include "vtkDataReader.h"
#include "vtkDataSetFilter.h"
#include "vtkDataSetMapper.h"
#include "vtkDataSetReader.h"
#include "vtkDataSetToDataSetFilter.h"
#include "vtkDataSetToPolyFilter.h"
#include "vtkDataSetToStructuredGridFilter.h"
#include "vtkDataSetToStructuredPointsFilter.h"
#include "vtkDataSetToUnstructuredGridFilter.h"
#include "vtkDataSetWriter.h"
#include "vtkDataWriter.h"
#include "vtkDecimate.h"
#include "vtkDelaunay2D.h"
#include "vtkDelaunay3D.h"
#include "vtkDicer.h"
#include "vtkDiskSource.h"
#include "vtkDividingCubes.h"
#include "vtkEarthSource.h"
#include "vtkEdgePoints.h"
#include "vtkElevationFilter.h"
#include "vtkExporter.h"
#include "vtkExtractEdges.h"
#include "vtkExtractGeometry.h"
#include "vtkExtractGrid.h"
#include "vtkExtractVOI.h"
#include "vtkExtractVectorComponents.h"
#include "vtkFeatureEdges.h"
#include "vtkFeatureVertices.h"
#include "vtkFilter.h"
#include "vtkFollower.h"
#include "vtkGaussianSplatter.h"
#include "vtkGeometryFilter.h"
#include "vtkGlyph3D.h"
#include "vtkHedgeHog.h"
#include "vtkHyperStreamline.h"
#include "vtkImageDifference.h"
#include "vtkImageToStructuredPoints.h"
#include "vtkImplicitBoolean.h"
#include "vtkImplicitDataSet.h"
#include "vtkImplicitModeller.h"
#include "vtkImplicitTextureCoords.h"
#include "vtkImplicitVolume.h"
#include "vtkImplicitWindowFunction.h"
#include "vtkLODActor.h"
#include "vtkLight.h"
#include "vtkLineSource.h"
#include "vtkLinearExtrusionFilter.h"
#include "vtkLinkEdgels.h"
#include "vtkLinkSurfels.h"
#include "vtkMCubesReader.h"
#include "vtkMCubesWriter.h"
#include "vtkMapper.h"
#include "vtkMarchingCubes.h"
#include "vtkMarchingSquares.h"
#include "vtkMaskPoints.h"
#include "vtkMaskPolyData.h"
#include "vtkMergeFilter.h"
#include "vtkMergePoints.h"
#include "vtkNewVolumeRenderer.h"
#include "vtkOBBTree.h"
#include "vtkOBJExporter.h"
#include "vtkOutlineFilter.h"
#include "vtkOutlineSource.h"
#include "vtkPLOT3DReader.h"
#include "vtkPNMReader.h"
#include "vtkPNMWriter.h"
#include "vtkPicker.h"
#include "vtkPlaneSource.h"
#include "vtkPlanes.h"
#include "vtkPointLoad.h"
#include "vtkPointPicker.h"
#include "vtkPointSetFilter.h"
#include "vtkPointSetToPointSetFilter.h"
#include "vtkPointSource.h"
#include "vtkPolyConnectivityFilter.h"
#include "vtkPolyFilter.h"
#include "vtkPolyMapper.h"
#include "vtkPolyMapperDevice.h"
#include "vtkPolyNormals.h"
#include "vtkPolyReader.h"
#include "vtkPolySource.h"
#include "vtkPolyToPolyFilter.h"
#include "vtkPolyWriter.h"
#include "vtkProbeFilter.h"
#include "vtkProperty.h"
#include "vtkQuadric.h"
#include "vtkRecursiveDividingCubes.h"
#include "vtkRenderMaster.h"
#include "vtkRenderWindow.h"
#include "vtkRenderWindowInteractor.h"
#include "vtkRenderer.h"
#include "vtkRendererCollection.h"
#include "vtkRendererSource.h"
#include "vtkRibbonFilter.h"
#include "vtkRotationalExtrusionFilter.h"
#include "vtkSTLReader.h"
#include "vtkSTLWriter.h"
#include "vtkSampleFunction.h"
#include "vtkShepardMethod.h"
#include "vtkShrinkFilter.h"
#include "vtkShrinkPolyData.h"
#include "vtkSliceCubes.h"
#include "vtkSmoothPolyFilter.h"
#include "vtkSpatialRepFilter.h"
#include "vtkSphere.h"
#include "vtkSphereSource.h"
#include "vtkStreamLine.h"
#include "vtkStreamPoints.h"
#include "vtkStreamer.h"
#include "vtkStripper.h"
#include "vtkStructuredGridFilter.h"
#include "vtkStructuredGridGeometryFilter.h"
#include "vtkStructuredGridOutlineFilter.h"
#include "vtkStructuredGridReader.h"
#include "vtkStructuredGridSource.h"
#include "vtkStructuredGridToPolyFilter.h"
#include "vtkStructuredGridToStructuredGridFilter.h"
#include "vtkStructuredGridWriter.h"
#include "vtkStructuredPointsFilter.h"
#include "vtkStructuredPointsGeometryFilter.h"
#include "vtkStructuredPointsReader.h"
#include "vtkStructuredPointsSource.h"
#include "vtkStructuredPointsToImage.h"
#include "vtkStructuredPointsToPolyDataFilter.h"
#include "vtkStructuredPointsToStructuredPointsFilter.h"
#include "vtkStructuredPointsWriter.h"
#include "vtkSubPixelPositionEdgels.h"
#include "vtkSweptSurface.h"
#include "vtkTensorGlyph.h"
#include "vtkTextSource.h"
#include "vtkTexture.h"
#include "vtkTextureMapToBox.h"
#include "vtkTextureMapToCylinder.h"
#include "vtkTextureMapToPlane.h"
#include "vtkTextureMapToSphere.h"
#include "vtkTexturedSphereSource.h"
#include "vtkThreshold.h"
#include "vtkThresholdPoints.h"
#include "vtkThresholdTextureCoords.h"
#include "vtkTransformFilter.h"
#include "vtkTransformPolyFilter.h"
#include "vtkTransformStructuredPoints.h"
#include "vtkTransformTextureCoords.h"
#include "vtkTriangleFilter.h"
#include "vtkTubeFilter.h"
#include "vtkUGFacetReader.h"
#include "vtkUnstructuredGridFilter.h"
#include "vtkUnstructuredGridReader.h"
#include "vtkUnstructuredGridSource.h"
#include "vtkUnstructuredGridWriter.h"
#include "vtkVRMLExporter.h"
#include "vtkVectorDot.h"
#include "vtkVectorNorm.h"
#include "vtkVectorText.h"
#include "vtkVectorTopology.h"
#include "vtkVolume.h"
#include "vtkVolume16Reader.h"
#include "vtkVolumeReader.h"
#include "vtkVolumeRenderer.h"
#include "vtkVoxelModeller.h"
#include "vtkVoxelReader.h"
#include "vtkVoxelWriter.h"
#include "vtkWarpScalar.h"
#include "vtkWarpTo.h"
#include "vtkWarpVector.h"
#include "vtkWriter.h"

==> vtk-v2.0.x.zip: vtk-v2.0.x/graphics/vtkGraphics.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkGraphics.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-1998 Ken Martin, Will Schroeder, Bill Lorensen.

This software is copyrighted by Ken Martin, Will Schroeder and Bill Lorensen.
The following terms apply to all files associated with the software unless
explicitly disclaimed in individual files. This copyright specifically does
not apply to the related textbook "The Visualization Toolkit" ISBN
013199837-4 published by Prentice Hall which is covered by its own copyright.

The authors hereby grant permission to use, copy, and distribute this
software and its documentation for any purpose, provided that existing
copyright notices are retained in all copies and that this notice is included
verbatim in any distributions. Additionally, the authors grant permission to
modify this software and its documentation for any purpose, provided that
such modifications are not distributed without the explicit consent of the
authors and that existing copyright notices are retained in all copies. Some
of the algorithms implemented by this software are patented, observe all
applicable patent law.

IN NO EVENT SHALL THE AUTHORS OR DISTRIBUTORS BE LIABLE TO ANY PARTY FOR
DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY DERIVATIVES THEREOF,
EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE IS PROVIDED ON AN
"AS IS" BASIS, AND THE AUTHORS AND DISTRIBUTORS HAVE NO OBLIGATION TO PROVIDE
MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.


=========================================================================*/

#include "vtkActor.h"
#include "vtkAppendFilter.h"
#include "vtkAppendPolyData.h"
#include "vtkAssembly.h"
#include "vtkAxes.h"
#include "vtkBYUReader.h"
#include "vtkBYUWriter.h"
#include "vtkBooleanStructuredPoints.h"
#include "vtkBooleanTexture.h"
#include "vtkBrownianPoints.h"
#include "vtkCamera.h"
#include "vtkCastToConcrete.h"
#include "vtkCellLocator.h"
#include "vtkCellPicker.h"
#include "vtkCleanPolyData.h"
#include "vtkClipPolyData.h"
#include "vtkCone.h"
#include "vtkConeSource.h"
#include "vtkConnectivityFilter.h"
#include "vtkContourFilter.h"
#include "vtkCubeSource.h"
#include "vtkCursor3D.h"
#include "vtkCutter.h"
#include "vtkCyberReader.h"
#include "vtkCylinder.h"
#include "vtkCylinderSource.h"
#include "vtkDashedStreamLine.h"
#include "vtkDataReader.h"
#include "vtkDataSetFilter.h"
#include "vtkDataSetMapper.h"
#include "vtkDataSetReader.h"
#include "vtkDataSetToDataSetFilter.h"
#include "vtkDataSetToPolyDataFilter.h"
#include "vtkDataSetToStructuredGridFilter.h"
#include "vtkDataSetToStructuredPointsFilter.h"
#include "vtkDataSetToUnstructuredGridFilter.h"
#include "vtkDataSetWriter.h"
#include "vtkDataWriter.h"
#include "vtkDelaunay2D.h"
#include "vtkDelaunay3D.h"
#include "vtkDicer.h"
#include "vtkDiskSource.h"
#include "vtkEdgePoints.h"
#include "vtkElevationFilter.h"
#include "vtkExporter.h"
#include "vtkExtractEdges.h"
#include "vtkExtractGeometry.h"
#include "vtkExtractGrid.h"
#include "vtkExtractVOI.h"
#include "vtkExtractVectorComponents.h"
#include "vtkFeatureEdges.h"
#include "vtkFeatureVertices.h"
#include "vtkFilter.h"
#include "vtkFollower.h"
#include "vtkGaussianSplatter.h"
#include "vtkGeometryFilter.h"
#include "vtkGlyph3D.h"
#include "vtkHedgeHog.h"
#include "vtkHyperStreamline.h"
#include "vtkImageDifference.h"
#include "vtkImageToStructuredPoints.h"
#include "vtkImplicitBoolean.h"
#include "vtkImplicitDataSet.h"
#include "vtkImplicitModeller.h"
#include "vtkImplicitTextureCoords.h"
#include "vtkImplicitVolume.h"
#include "vtkImplicitWindowFunction.h"
#include "vtkLODActor.h"
#include "vtkLight.h"
#include "vtkLineSource.h"
#include "vtkLinearExtrusionFilter.h"
#include "vtkLinkEdgels.h"
#include "vtkMCubesReader.h"
#include "vtkMCubesWriter.h"
#include "vtkMapper.h"
#include "vtkMaskPoints.h"
#include "vtkMaskPolyData.h"
#include "vtkMergeFilter.h"
#include "vtkMergePoints.h"
#include "vtkOBBTree.h"
#include "vtkOBJExporter.h"
#include "vtkOutlineFilter.h"
#include "vtkOutlineSource.h"
#include "vtkPLOT3DReader.h"
#include "vtkPNMWriter.h"
#include "vtkPicker.h"
#include "vtkPlaneSource.h"
#include "vtkPlanes.h"
#include "vtkPointLoad.h"
#include "vtkPointPicker.h"
#include "vtkPointSetFilter.h"
#include "vtkPointSetToPointSetFilter.h"
#include "vtkPointSource.h"
#include "vtkPolyDataConnectivityFilter.h"
#include "vtkPolyDataFilter.h"
#include "vtkPolyDataMapper.h"
#include "vtkPolyDataNormals.h"
#include "vtkPolyDataReader.h"
#include "vtkPolyDataSource.h"
#include "vtkPolyDataToPolyDataFilter.h"
#include "vtkPolyDataWriter.h"
#include "vtkProbeFilter.h"
#include "vtkProjectedPolyDataRayBounder.h"
#include "vtkProperty.h"
#include "vtkQuadric.h"
#include "vtkRayBounder.h"
#include "vtkRecursiveDividingCubes.h"
#include "vtkRenderWindow.h"
#include "vtkRenderWindowInteractor.h"
#include "vtkRenderer.h"
#include "vtkRendererCollection.h"
#include "vtkRendererSource.h"
#include "vtkRibbonFilter.h"
#include "vtkRotationalExtrusionFilter.h"
#include "vtkSLCReader.h"
#include "vtkSTLReader.h"
#include "vtkSTLWriter.h"
#include "vtkSampleFunction.h"
#include "vtkShepardMethod.h"
#include "vtkShrinkFilter.h"
#include "vtkShrinkPolyData.h"
#include "vtkSpatialRepresentationFilter.h"
#include "vtkSphere.h"
#include "vtkSphereSource.h"
#include "vtkStreamLine.h"
#include "vtkStreamPoints.h"
#include "vtkStreamer.h"
#include "vtkStripper.h"
#include "vtkStructuredGridFilter.h"
#include "vtkStructuredGridGeometryFilter.h"
#include "vtkStructuredGridOutlineFilter.h"
#include "vtkStructuredGridReader.h"
#include "vtkStructuredGridSource.h"
#include "vtkStructuredGridToPolyDataFilter.h"
#include "vtkStructuredGridToStructuredGridFilter.h"
#include "vtkStructuredGridWriter.h"
#include "vtkStructuredPointsFilter.h"
#include "vtkStructuredPointsGeometryFilter.h"
#include "vtkStructuredPointsReader.h"
#include "vtkStructuredPointsSource.h"
#include "vtkStructuredPointsToImage.h"
#include "vtkStructuredPointsToPolyDataFilter.h"
#include "vtkStructuredPointsToStructuredPointsFilter.h"
#include "vtkStructuredPointsWriter.h"
#include "vtkSubPixelPositionEdgels.h"
#include "vtkTensorGlyph.h"
#include "vtkTextSource.h"
#include "vtkTexture.h"
#include "vtkTextureMapToBox.h"
#include "vtkTextureMapToCylinder.h"
#include "vtkTextureMapToPlane.h"
#include "vtkTextureMapToSphere.h"
#include "vtkTexturedSphereSource.h"
#include "vtkThreshold.h"
#include "vtkThresholdPoints.h"
#include "vtkThresholdTextureCoords.h"
#include "vtkTransformFilter.h"
#include "vtkTransformPolyDataFilter.h"
#include "vtkTransformTextureCoords.h"
#include "vtkTriangleFilter.h"
#include "vtkTubeFilter.h"
#include "vtkUGFacetReader.h"
#include "vtkUnstructuredGridFilter.h"
#include "vtkUnstructuredGridReader.h"
#include "vtkUnstructuredGridSource.h"
#include "vtkUnstructuredGridWriter.h"
#include "vtkVRMLExporter.h"
#include "vtkVectorDot.h"
#include "vtkVectorNorm.h"
#include "vtkVectorText.h"
#include "vtkVectorTopology.h"
#include "vtkVolume.h"
#include "vtkVolume16Reader.h"
#include "vtkVolumeCollection.h"
#include "vtkVolumeProperty.h"
#include "vtkVolumeRayCastCompositeFunction.h"
#include "vtkVolumeRayCastFunction.h"
#include "vtkVolumeRayCastMapper.h"
#include "vtkVolumeReader.h"
#include "vtkVoxelModeller.h"
#include "vtkWarpScalar.h"
#include "vtkWarpTo.h"
#include "vtkWarpVector.h"
#include "vtkWriter.h"
